@@ -5,14 +5,12 @@ use warnings;
 
 # ABSTRACT: A ProcPolicy that treats scalars items and pass other types as-is.
 
-our $VERSION = '1.111720'; # VERSION
+our $VERSION = '1.111750'; # VERSION
 
 use Moose;
 with 'DataFlow::Role::ProcPolicy';
 
 use namespace::autoclean;
-use Data::Alias;
-use Data::Dumper;
 
 has 'spec' => (
     is       => 'ro',
@@ -58,7 +56,7 @@ DataFlow::Policy::WithSpec - A ProcPolicy that treats scalars items and pass oth
 
 =head1 VERSION
 
-version 1.111720
+version 1.111750
 
 =head1 SEE ALSO
 
